@@ -118,7 +118,7 @@ class Service:
                 executable = sys.executable,
                 serve = serve,
                 working_dir = self.working_dir,
-                pidfile = os.path.join (self.lockpath, '.pid'),
+                pidfile = name,
                 args = " ".join (['"{}"'.format (each) for each in args])
             )
 
@@ -163,7 +163,7 @@ After=syslog.target network.target
 
 [Service]
 Type=forking
-PIDFile={pidfile}
+PIDFile=/var/run/{pidfile}.pid
 WorkingDirectory={working_dir}
 User={user}
 Group={user}
